@@ -27,10 +27,13 @@ static CORBA_long
 impl_bonobo_control_frame_accessible_get_child_count (PortableServer_Servant servant,
 						      CORBA_Environment *ev)
 {
-  BonoboControlFrameAccessible *frame_accessible =
-      BONOBO_CONTROL_FRAME_ACCESSIBLE (bonobo_object_from_servant (servant));
-
-  dprintf ("Accessibility::Accessible::_get_ChildCount [%p]\n", frame_accessible);
+  BonoboControlFrameAccessible *frame_accessible = NULL;
+  if (BONOBO_IS_CONTROL_FRAME_ACCESSIBLE (bonobo_object_from_servant (servant)))
+  {
+      frame_accessible = 
+	  BONOBO_CONTROL_FRAME_ACCESSIBLE (bonobo_object_from_servant (servant));
+  }
+  debug_printf ("Accessibility::Accessible::_get_ChildCount [%p]\n", frame_accessible);
 
   g_return_val_if_fail (frame_accessible != NULL, 0);
   g_return_val_if_fail (frame_accessible->control_frame != NULL, 0);
@@ -44,11 +47,15 @@ impl_bonobo_control_frame_accessible_get_child_at_index (PortableServer_Servant
 							 CORBA_long index,
 							 CORBA_Environment *ev)
 {
-  BonoboControlFrameAccessible *frame_accessible =
-      BONOBO_CONTROL_FRAME_ACCESSIBLE (bonobo_object_from_servant (servant));
+  BonoboControlFrameAccessible *frame_accessible = NULL;
+  if (BONOBO_IS_CONTROL_FRAME_ACCESSIBLE (bonobo_object_from_servant (servant)))
+  {
+      frame_accessible = 
+	  BONOBO_CONTROL_FRAME_ACCESSIBLE (bonobo_object_from_servant (servant));
+  }
   Bonobo_Control control;
 
-  dprintf ("Accessibility::Accessible::getChildAtIndex [%p]\n", frame_accessible);
+  debug_printf ("Accessibility::Accessible::getChildAtIndex [%p]\n", frame_accessible);
 
   g_return_val_if_fail (frame_accessible != NULL, CORBA_OBJECT_NIL);
   g_return_val_if_fail (frame_accessible->control_frame != NULL, CORBA_OBJECT_NIL);
@@ -56,6 +63,8 @@ impl_bonobo_control_frame_accessible_get_child_at_index (PortableServer_Servant
   
   control = bonobo_control_frame_get_control (frame_accessible->control_frame);
 
+  g_return_val_if_fail (control != NULL, CORBA_OBJECT_NIL);
+
   return Bonobo_Control_getAccessible (control, ev);
 }
 
@@ -85,6 +94,8 @@ bonobo_control_frame_accessible_new (BonoboControlFrame *control_frame)
   GtkWidget *widget;
   AtkObject *atko;
 
+  debug_printf ("bonobo_control_frame_accessible_new [%p]\n", control_frame);
+
   g_return_val_if_fail (control_frame != NULL, NULL);
   widget = bonobo_control_frame_get_widget (control_frame);
   g_assert (widget != NULL);
